@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Search.py,v 1.10.2.1 2000/06/07 12:43:26 fredgo Exp $
+# $Id: Search.py,v 1.10.2.3 2000/09/25 11:14:02 fredgo Exp $
 
 from gnome.ui import *
 from gtk import *
@@ -113,7 +113,7 @@ class SearchDialog (GnomeDialog, Connector.Publisher):
         
         if parent: self.set_parent (parent)
 
-        self.button_connect (0, self.apply_cb)
+        self.button_connect (0, self.apply_button_cb)
         self.button_connect (1, self.close_cb)
         self.set_default (0)
         self.close_hides (1)
@@ -137,6 +137,8 @@ class SearchDialog (GnomeDialog, Connector.Publisher):
         table.attach (self.field, 0, 1, 1, 2)
 
         self.text = GnomeEntry ('match')
+        self.text.load_history ()
+        
         table.attach (self.text, 1, 2, 1, 2)
         self.text.gtk_entry ().connect ('activate', self.apply_cb)
 
@@ -182,8 +184,11 @@ class SearchDialog (GnomeDialog, Connector.Publisher):
         self.show_all ()
         return
 
-    def destroyed (self, * arg):
-        print "nooo !"
+
+    def update_configuration (self):
+        self.text.save_history ()
+        return
+
         
     def create_root_item (self, data):
         if self.root_item:
@@ -201,6 +206,15 @@ class SearchDialog (GnomeDialog, Connector.Publisher):
         self.close ()
         return
     
+
+    def apply_button_cb (self, widget):
+        if self.notebook.get_current_page () == 0:
+            self.text.append_history (TRUE,
+                                      self.text.gtk_entry ().get_text ())
+            return
+
+        self.apply_cb (self, widget)
+        return
     
     def apply_cb (self, widget):
         page = self.notebook.get_current_page ()
