@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: author.c,v 1.7 1999/08/31 13:08:46 gobry Exp $
+ $Id: author.c,v 1.1.1.1.2.1 2000/10/30 09:07:06 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -144,6 +144,8 @@ btgroup_destroy (BTGroup * group) {
     g_chunk_free (group, chunk);
 }
 
+/* this function adds the comma separated blocks to the token list */
+
 static GList *
 split_spaces (GList * tokens,
 	      gchar * data,
@@ -218,8 +220,9 @@ tokenify (GList * tokens,
 	    /* Deal with eventual commands */
 	    switch (tmp_s->type) {
 	    case BIBTEX_STRUCT_COMMAND:
+
 		courant = bibtex_accent_string (tmp_s, & tmp, NULL);
-		tokens = split_spaces (tokens, courant, level);
+		tokens  = split_spaces (tokens, courant, level);
 		g_free (courant);
 		break;
 		    
@@ -281,31 +284,34 @@ void
 extract_author (BibtexAuthorGroup * authors,
 		GList * aut_elem) {
 
+#define SECTION_LENGTH 4
+
     GList * tokens, * tmp;
     gchar * text, * tmp_text;
     BibtexAuthor * author;
-    gint length;
-    guint commas;
-    GPtrArray * first, * second, * third, * array;
+    gint length, i;
+    guint sections, comas;
+    GPtrArray * section [SECTION_LENGTH], * array;
     BTGroup * group;
 
+    gint lastname_section;
+
     /* Room for the new author */
     g_array_set_size (authors, authors->len + 1);
     author = & g_array_index (authors, BibtexAuthor, authors->len - 1);
 
-    author->first = NULL;
-    author->last = NULL;
+    author->first     = NULL;
+    author->last      = NULL;
     author->honorific = NULL;
-    author->lineage = NULL;
+    author->lineage   = NULL;
 
-    first  = g_ptr_array_new ();
-    second = g_ptr_array_new ();
-    third  = g_ptr_array_new ();
+    for (i = 0; i < SECTION_LENGTH; i ++) {
+	section [i]  = g_ptr_array_new ();
+    }
     
-    /* Parse the list into two groups */
-    tmp = aut_elem;
-    commas = 0;
-    array = first;
+    /* count the , */
+    tmp   = aut_elem;
+    comas = 0;
 
     while (tmp) {
 	group = (BTGroup *) tmp->data;
@@ -315,91 +321,147 @@ extract_author (BibtexAuthorGroup * authors,
 
 	/* Check for , syntax */
 	if (strcmp (",", text) == 0) {
-	    commas ++;
+	  comas ++;
+	}
+    }
 
-	    switch (commas) {
-	    case 1:
-		array = second;
-		break;
-	    case 2:
-		array = third;
-		break;
+    /* Parse the list into several groups */
+
+    tmp      = aut_elem;
+    array    = section [0];
+    sections = 0;
+
+    lastname_section = -1;
+
+    while (tmp) {
+	group = (BTGroup *) tmp->data;
+	text = group->text;
+
+	tmp = tmp->next;
+
+	/* Check for , syntax */
+	if (strcmp (",", text) == 0) {
+
+	    /* skip eventual empty sections */
+	    if (array->len) {
+		sections ++;
+
+		/* only consider the 3 first sections */
+		if (sections < SECTION_LENGTH)
+		    array = section [sections];
 	    }
+
+	    lastname_section = -1;
 	    continue;
 	}
 
-	/* If we have the particule */
-	if (group->level == 1 && islower (text [0])) {
-	    array = second;
+	/* If we have the particule in lowercase */
+	if (group->level == 1  &&
+	    comas == 0         &&
+	    islower (text [0]) && 
+	    lastname_section == -1) {
+
+	    if (array->len) {
+		sections ++;
+		
+		/* only consider the 3 first sections */
+		if (sections < SECTION_LENGTH)
+		    array = section [sections];
+	    }
+
+	    lastname_section = sections;
 
 	    g_strdown (text);
 	    g_ptr_array_add (array, text);
 	    continue;
 	}
 
+	/* default, add new text */
 	g_ptr_array_add (array, text);
     }
 
+    /* 
+       Compact the sections to skip the empty ones. Intermediate sections are
+       already compressed. we only have to check the last one.
+     */
 
-    switch (commas) {
+    if (array->len == 0) {
+	sections --;
+	comas    --;
+    }
+
+    if (sections < comas) {
+	comas = sections;
+    }
+
+    switch (comas) {
     case 1:
-	/* Format: Last Name, First Name */
+	/* Format: <Last Name>, <First Name> */
 
-	g_ptr_array_add (first, NULL);
-	g_ptr_array_add (second, NULL);
+	g_ptr_array_add (section [0], NULL);
+	g_ptr_array_add (section [1], NULL);
 
-	author->last  = g_strjoinv (" ", (gchar **) first->pdata);
+	author->last  = g_strjoinv (" ", (gchar **) section [0]->pdata);
 
-	if (second->len > 1) {
-	    author->first = g_strjoinv (" ", (gchar **) second->pdata);
+	if (section [1]->len > 1) {
+	    author->first = g_strjoinv (" ", (gchar **) section [1]->pdata);
 	}
 	break;
 
     case 0:
 	/* Format: <prenom...> [von|de|du|del] <nom> */
 
-	/* If there is no `von' */
-	if (second->len == 0) {
-	    g_ptr_array_add (second, 
-			     g_ptr_array_index (first, first->len - 1));
-	    g_ptr_array_index (first, first->len - 1) = NULL;
+	/* If there is no lowercase word indicating the last name */
+	if (lastname_section == -1) {
+	    /* simply take the last word of the first sequence */
+	    g_ptr_array_add (section [1], 
+			     g_ptr_array_index (section [0], section [0]->len - 1));
+	    g_ptr_array_index (section [0], section [0]->len - 1) = NULL;
+
+	    lastname_section = 1;
 	}
 	else {
-	    g_ptr_array_add (first, NULL);
+	    g_ptr_array_add (section [0], NULL);
 	}
 	
-	g_ptr_array_add (second, NULL);
+	g_ptr_array_add (section [1], NULL);
 
-	if (first->len > 1) {
-	    author->first = g_strjoinv (" ", (gchar **) first->pdata);
+	if (section [0]->len > 1) {
+	    author->first = g_strjoinv (" ", (gchar **) section [0]->pdata);
 	}
-	author->last  = g_strjoinv (" ", (gchar **) second->pdata);
+
+	author->last  = g_strjoinv (" ", (gchar **) section [lastname_section]->pdata);
 	break;
 
     case 2:
-	/* Format: <firstname> <von> <lastname> <jr> */
+	/* Format: <lastname>, <lineage>, <firstname> */
+	g_ptr_array_add (section [0], NULL);
+	g_ptr_array_add (section [1], NULL);
+	g_ptr_array_add (section [2], NULL);
 
-	/* If there is no `von' */
-	if (third->len == 0) {
-	    g_ptr_array_add (third, g_ptr_array_index (first, first->len - 1));
-	    g_ptr_array_index (first, first->len - 1) = NULL;
-	}
-	else {
-	    g_ptr_array_add (first, NULL);
-	}
-	
-	g_ptr_array_add (second, NULL);
-	g_ptr_array_add (third, NULL);
+	author->last    = g_strjoinv (" ", (gchar **) section [0]->pdata);
+	author->lineage = g_strjoinv (" ", (gchar **) section [1]->pdata);
+	author->first   = g_strjoinv (" ", (gchar **) section [2]->pdata);
+	break;
 
-	author->last    = g_strjoinv (" ", (gchar **) first->pdata);
-	author->first   = g_strjoinv (" ", (gchar **) third->pdata);
-	author->lineage = g_strjoinv (" ", (gchar **) second->pdata);
+    default:
+	/* too many comas... */
+	bibtex_warning ("too many comas in author definition");
+
+	g_ptr_array_add (section [0], NULL);
+	g_ptr_array_add (section [1], NULL);
+
+	author->last  = g_strjoinv (" ", (gchar **) section [0]->pdata);
+
+	if (section [1]->len > 1) {
+	    author->first = g_strjoinv (" ", (gchar **) section [1]->pdata);
+	}
 	break;
     }
 
-    g_ptr_array_free (first, TRUE);
-    g_ptr_array_free (second, TRUE);
-    g_ptr_array_free (third, TRUE);
+    for (i = 0; i < SECTION_LENGTH; i ++) {
+	g_ptr_array_free (section [i], TRUE);
+    }
 }
 
 BibtexAuthorGroup *
@@ -416,6 +478,8 @@ bibtex_author_parse (BibtexStruct * s,
     GList * target;
     BTGroup * group, * tmp_g;
     gboolean compact, first_pass;
+    gint i;
+
 
     g_return_val_if_fail (s != NULL, NULL);
 
@@ -426,6 +490,13 @@ bibtex_author_parse (BibtexStruct * s,
        -------------------------------------------------- */
 
     tokens = tokenify (NULL, s, 0, dico);
+    list = tokens;
+
+    while (list) {
+	group = (BTGroup *) list->data;
+
+	list = list->next;
+    }
 
     /* --------------------------------------------------
        Compact the strings as much as possible 
@@ -447,11 +518,11 @@ bibtex_author_parse (BibtexStruct * s,
 	    
 	    /* Capitalize only during first pass, as we can compact entries
 	       from different levels afterward... */
-	    if (first_pass) {
-		if (group->level == 1 && isupper (text [0])) {
-		    bibtex_capitalize (text, TRUE, skip);
-		}
-	    }
+/*  	    if (first_pass) { */
+/*  		if (group->level == 1 && isupper (text [0])) { */
+/*  		    bibtex_capitalize (text, TRUE, skip); */
+/*  		} */
+/*  	    } */
 	    
 	    /* Skip and remove spaces */
 	    if (strcmp (" ", text) == 0) {
@@ -526,13 +597,6 @@ bibtex_author_parse (BibtexStruct * s,
        Heuristic to extract authors... 
        -------------------------------------------------- */
 
-/*      list = tokens; */
-/*      while (list) { */
-/*  	printf ("(%s)", ((BTGroup *) list->data)->text); */
-/*  	list = list->next; */
-/*      } */
-/*      printf ("\n"); */
-
     aut_elem = NULL;	
     list = tokens;
 
