@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: recodemodule.c,v 1.1.1.1.2.1 2000/09/19 15:50:05 fredgo Exp $
+ $Id: recodemodule.c,v 1.1.1.1.2.2 2000/10/17 13:02:39 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -151,7 +151,7 @@ static PyMethodDef recodeMeth [] = {
 };
 
 
-void init_recode ()
+void init_recode (void)
 {
     outer = recode_new_outer (false);
     if (outer == NULL) return;
